==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/equipmentmeterreadingdefault_001/EquipmentMeterReadingDefault.java <==

package net.datastream.schemas.mp_entities.equipmentmeterreadingdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.READINGTYPEID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="hasupdownmeterchecked" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "readingtypeid",
    "readingdate",
    "rstatus",
    "uomid"
})
@XmlRootElement(name = "EquipmentMeterReadingDefault")
public class EquipmentMeterReadingDefault {

    @XmlElement(name = "READINGTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected READINGTYPEID_Type readingtypeid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlAttribute(name = "hasupdownmeterchecked")
    protected String hasupdownmeterchecked;

    /**
     * Gets the value of the readingtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public READINGTYPEID_Type getREADINGTYPEID() {
        return readingtypeid;
    }

    /**
     * Sets the value of the readingtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public void setREADINGTYPEID(READINGTYPEID_Type value) {
        this.readingtypeid = value;
    }

    /**
     * Gets the value of the readingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Sets the value of the readingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the hasupdownmeterchecked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHasupdownmeterchecked() {
        if (hasupdownmeterchecked == null) {
            return "false";
        } else {
            return hasupdownmeterchecked;
        }
    }

    /**
     * Sets the value of the hasupdownmeterchecked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHasupdownmeterchecked(String value) {
        this.hasupdownmeterchecked = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equipmentmeterreadingdefault_001/EquipmentMeterReadingDefault.java <==

package net.datastream.schemas.mp_entities.equipmentmeterreadingdefault_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.READINGTYPEID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}READINGTYPEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="hasupdownmeterchecked" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "readingtypeid",
    "readingdate",
    "rstatus",
    "uomid"
})
@XmlRootElement(name = "EquipmentMeterReadingDefault")
public class EquipmentMeterReadingDefault {

    @XmlElement(name = "READINGTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected READINGTYPEID_Type readingtypeid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlAttribute(name = "hasupdownmeterchecked")
    protected String hasupdownmeterchecked;

    /**
     * Gets the value of the readingtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public READINGTYPEID_Type getREADINGTYPEID() {
        return readingtypeid;
    }

    /**
     * Sets the value of the readingtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public void setREADINGTYPEID(READINGTYPEID_Type value) {
        this.readingtypeid = value;
    }

    /**
     * Gets the value of the readingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Sets the value of the readingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the hasupdownmeterchecked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHasupdownmeterchecked() {
        if (hasupdownmeterchecked == null) {
            return "false";
        } else {
            return hasupdownmeterchecked;
        }
    }

    /**
     * Sets the value of the hasupdownmeterchecked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHasupdownmeterchecked(String value) {
        this.hasupdownmeterchecked = value;
    }

}
